==> nextcloud-app-deck-1%3A0.6.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/vi.js <==
OC.L10N.register(
    "deck",
    {
    "The associated stack is deleted as well, it will be restored as well." : "Giai đoạn liên quan đã bị xóa, nó cũng có thể được khôi phục lại.",
    "Restore associated stack" : "Khôi phục giai đoạn được liên kết",
    "Remove user from card" : "Loại bỏ người dùng khỏi tác vụ",
    "Hours" : "Giờ",
    "Minutes" : "Phút",
    "Maximum file size of {size} exceeded" : "Đã vượt quá kích thước {size} tối đa tập tin",
    "You have created a new board {board}" : "Bạn đã tạo một dự án mới {board}",
    "{user} has created a new board {board}" : "{user} đã tạo một dự án mới {board}",
    "You have deleted the board {board}" : "Bạn đã xóa một dự án {board}",
    "{user} has deleted the board {board}" : "{user} đã xóa một dự án {board}",
    "You have restored the board {board}" : "Bạn đã khôi phục lại dự án {board}",
    "{user} has restored the board {board}" : "{user} đã khôi phục dự án {board}",
    "You have shared the board {board} with {acl}" : "Bạn đã chia sẽ dự án {board} với {acl}",
    "You have removed {acl} from the board {board}" : "Bạn đã loại bỏ {acl} khỏi dự án {board}",
    "{user} has removed {acl} from the board {board}" : "{user} đã loại bỏ {acl} khỏi dự án {board}",
    "You have renamed the board {before} to {board}" : "Bạn đã đổi tên dự án từ {before} thành {board}",
    "You have archived the board {board}" : "Bạn đã lưu trữ dự án {board}",
    "{user} has archived the board {before}" : "{user} đã lưu trữ dự án {before}",
    "You have unarchived the board {board}" : "Bạn đã bỏ lưu trữ dự án {board}",
    "{user} has unarchived the board {before}" : "{user} đã bỏ lưu trữ dự án {before}",
    "You have renamed the card {before} to {card}" : "Bạn đã thay đổi tên của tác vụ {before} thành {card}",
    "{user} has renamed the card {before} to {card}" : "{user} đã thay đổi tên của tác vụ {before} thành {card}",
    "Deck" : "Kế hoạch",
    "Personal" : "Cá nhân",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Tác vụ \"%s\" trong \"%s\" đã được phân công cho bạn bởi  %s.",
    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} đã phân công tác vụ \"%s\" trong \"%s\" cho bạn.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Tác vụ \"%s\" trong \"%s\" đã đến ngày hạn chót.",
    "The board \"%s\" has been shared with you by %s." : "Dự án \"%s\" đã được chia sẽ với bạn bởi %s .",
    "{user} has shared the board %s with you." : "{user} đã chia sẽ dự án %s với bạn.",
    "No data was provided to create an attachment." : "Không có dữ liệu từ nhà cung cấp để tạo một đính kèm",
    "Finished" : "Đã hoàn tất",
    "To review" : "Xem thử",
    "Action needed" : "Cần thực hiện",
    "Later" : "Để sau",
    "To do" : "Cần làm",
    "Doing" : "Đang làm",
    "Done" : "Hoàn tất",
    "Example Task 3" : "Nhiệm vụ ví dụ 3",
    "Example Task 2" : "Nhiệm vụ ví dụ 2",
    "Example Task 1" : "Nhiệm vụ ví dụ 1",
    "The file was uploaded" : "Tập tin đã được tải lên",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tập tin tải lên đã vượt quá upload_max_filesize giới hạn trong hệ thống",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tập được tải lên vượt quá MAX_FILE_SIZE đã được giới hạn trong biểu mẫu HTML",
    "The file was only partially uploaded" : "Tệp chỉ được tải lên một phần",
    "No file was uploaded" : "Chưa có tệp nào dược tải lên",
    "Missing a temporary folder" : "Thiếu một thư mục tạm thời",
    "Could not write file to disk" : "Không thể ghi tệp lên hệ thống",
    "A PHP extension stopped the file upload" : "Một chức năng mở rộng của PHP đã dừng tải tệp lên",
    "No file uploaded or file size exceeds maximum of %s" : "Chưa có tệp nào được tải lên hoặc kích thước tệp vượt quá giới hạn của %s",
    "A kanban style project and personal management tool for Nextcloud" : "Dự án theo kiểu kanban và công cụ quản lý cá nhân cho Hệ thống",
    "Add a new stack" : "Thêm một giai đoạn mới",
    "Submit" : "Gửi đi",
    "Show archived cards" : "Hiện tác vụ đã lưu trữ",
    "Hide archived cards" : "Ẩn tác vụ đã lưu trữ",
    "Toggle compact mode" : "Chuyển đổi chế độ thu gọn",
    "All Boards" : "Tất cả dự án",
    "Archived boards" : "Dự án đã lưu trữ",
    "Share board" : "Dự án chia sẽ",
    "Actions" : "Hành động",
    "Drop your files here to upload it to the card" : "Thả tệp của bạn vào đây để tải nó lên tác vụ",
    "Enter a card title" : "Nhập tên tác vụ",
    "Add card" : "Thêm tác vụ",
    "Close" : "Đóng",
    "Sharing" : "Đang chia sẽ",
    "Tags" : "Thẻ",
    "Select users or groups to share with" : "Chọn người dùng hoặc nhóm để chia sẽ với",
    "No matching user or group found." : "Không tìm thấy người dùng hoặc nhóm.",
    "Loading" : "Đang tải",
    "Edit" : "Chỉnh sửa",
    "Share" : "Chia sẽ",
    "Manage" : "Quản lý",
    "Discard share" : "Hủy chia sẽ",
    "Create" : "Tạo",
    "Create a new tag" : "Tạo một thẻ mới",
    "Status" : "Trạng thái",
    "No archived boards to display" : "Không có dự án đã lưu trữ nào để hiển thị",
    "No shared boards to display" : "Không có dự án đã được chia sẽ nào để hiển thị",
    "Title" : "Tên",
    "Members" : "Thành viên",
    "More actions" : "Nhiều hành động hơn",
    "Edit board" : "Chỉnh sửa dự án",
    "Archive board" : "Lưu trữ dự án",
    "Unarchive board" : "Bỏ lưu trữ dự án",
    "Delete board" : "Xóa dự án",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Hoàn tác dự án đã xóa - Nếu không, Dự án sẽ bị xóa trong lần quét Hệ thống tiếp theo.",
    "Create new board" : "Tạo dự án mới",
    "New board title" : "Tên dự án mới",
    "Select an attachment" : "Chọn một đính kèm",
    "Cancel upload" : "Hủy tải lên",
    "by" : "bởi",
    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "Hoàn tác file đã xóa - Nếu không, file sẽ bị xóa trong lần quét hệ thống tiếp theo.",
    "Undo file deletion" : "Hoàn tác file đã xóa",
    "Insert the file into the description" : "Chèn tệp vào mô tả",
    "Modified:" : "Đã sửa:",
    "Created:" : "Đã tạo:",
    "Choose a tag" : "Chọn một thẻ",
    "Add a tag" : "Thêm một thẻ",
    "Select tags" : "Chọn một thẻ",
    "Assign users" : "Chỉ định người dùng",
    "Choose a user to assign" : "Chọn một người dùng để phân công",
    "Assign this card to a user" : "Phân công tác vụ cho người dùng",
    "Due date" : "Thời hạn",
    "Click to set" : "Bấm để thiết đặt",
    "Remove due date" : "Xóa thời hạn",
    "Description" : "Mô tả",
    "Attachments" : "Đính kèm",
    "Saved" : "Đã lưu",
    "Unsaved changes" : "Thay đổi chưa được lưu",
    "Insert attachment" : "Thêm đính kèm",
    "Formatting help" : "Định dạng trợ giúp",
    "Upload attachment" : "Tải lên một đính kèm",
    "Add a card description…" : "Thêm một mô tả tác vụ...",
    "Shared boards" : "Chia sẽ dự án",
    "Move board to archive" : "Di chuyển dự án sang lưu trữ",
    "Create a new board" : "Tạo dự án mới"
},
"nplurals=1; plural=0;");

==> nextcloud-app-deck-1%3A0.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/vi.js <==
OC.L10N.register(
    "deck",
    {
    "The associated stack is deleted as well, it will be restored as well." : "Giai đoạn liên quan đã bị xóa, nó cũng có thể được khôi phục lại.",
    "Restore associated stack" : "Khôi phục giai đoạn được liên kết",
    "Remove user from card" : "Loại bỏ người dùng khỏi tác vụ",
    "Hours" : "Giờ",
    "Minutes" : "Phút",
    "Maximum file size of {size} exceeded" : "Đã vượt quá kích thước {size} tối đa tập tin",
    "You have created a new board {board}" : "Bạn đã tạo một dự án mới {board}",
    "{user} has created a new board {board}" : "{user} đã tạo một dự án mới {board}",
    "You have deleted the board {board}" : "Bạn đã xóa một dự án {board}",
    "{user} has deleted the board {board}" : "{user} đã xóa một dự án {board}",
    "You have restored the board {board}" : "Bạn đã khôi phục lại dự án {board}",
    "{user} has restored the board {board}" : "{user} đã khôi phục dự án {board}",
    "You have shared the board {board} with {acl}" : "Bạn đã chia sẽ dự án {board} với {acl}",
    "You have removed {acl} from the board {board}" : "Bạn đã loại bỏ {acl} khỏi dự án {board}",
    "{user} has removed {acl} from the board {board}" : "{user} đã loại bỏ {acl} khỏi dự án {board}",
    "You have renamed the board {before} to {board}" : "Bạn đã đổi tên dự án từ {before} thành {board}",
    "You have archived the board {board}" : "Bạn đã lưu trữ dự án {board}",
    "{user} has archived the board {before}" : "{user} đã lưu trữ dự án {before}",
    "You have unarchived the board {board}" : "Bạn đã bỏ lưu trữ dự án {board}",
    "{user} has unarchived the board {before}" : "{user} đã bỏ lưu trữ dự án {before}",
    "You have renamed the card {before} to {card}" : "Bạn đã thay đổi tên của tác vụ {before} thành {card}",
    "{user} has renamed the card {before} to {card}" : "{user} đã thay đổi tên của tác vụ {before} thành {card}",
    "Deck" : "Kế hoạch",
    "Personal" : "Cá nhân",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Tác vụ \"%s\" trong \"%s\" đã được phân công cho bạn bởi  %s.",
    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} đã phân công tác vụ \"%s\" trong \"%s\" cho bạn.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Tác vụ \"%s\" trong \"%s\" đã đến ngày hạn chót.",
    "The board \"%s\" has been shared with you by %s." : "Dự án \"%s\" đã được chia sẽ với bạn bởi %s .",
    "{user} has shared the board %s with you." : "{user} đã chia sẽ dự án %s với bạn.",
    "No data was provided to create an attachment." : "Không có dữ liệu từ nhà cung cấp để tạo một đính kèm",
    "Finished" : "Đã hoàn tất",
    "To review" : "Xem thử",
    "Action needed" : "Cần thực hiện",
    "Later" : "Để sau",
    "To do" : "Cần làm",
    "Doing" : "Đang làm",
    "Done" : "Hoàn tất",
    "Example Task 3" : "Nhiệm vụ ví dụ 3",
    "Example Task 2" : "Nhiệm vụ ví dụ 2",
    "Example Task 1" : "Nhiệm vụ ví dụ 1",
    "The file was uploaded" : "Tập tin đã được tải lên",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tập tin tải lên đã vượt quá upload_max_filesize giới hạn trong hệ thống",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tập được tải lên vượt quá MAX_FILE_SIZE đã được giới hạn trong biểu mẫu HTML",
    "The file was only partially uploaded" : "Tệp chỉ được tải lên một phần",
    "No file was uploaded" : "Chưa có tệp nào dược tải lên",
    "Missing a temporary folder" : "Thiếu một thư mục tạm thời",
    "Could not write file to disk" : "Không thể ghi tệp lên hệ thống",
    "A PHP extension stopped the file upload" : "Một chức năng mở rộng của PHP đã dừng tải tệp lên",
    "No file uploaded or file size exceeds maximum of %s" : "Chưa có tệp nào được tải lên hoặc kích thước tệp vượt quá giới hạn của %s",
    "A kanban style project and personal management tool for Nextcloud" : "Dự án theo kiểu kanban và công cụ quản lý cá nhân cho Hệ thống",
    "Add a new stack" : "Thêm một giai đoạn mới",
    "Submit" : "Gửi đi",
    "Show archived cards" : "Hiện tác vụ đã lưu trữ",
    "Hide archived cards" : "Ẩn tác vụ đã lưu trữ",
    "Toggle compact mode" : "Chuyển đổi chế độ thu gọn",
    "All Boards" : "Tất cả dự án",
    "Archived boards" : "Dự án đã lưu trữ",
    "Share board" : "Dự án chia sẽ",
    "Actions" : "Hành động",
    "Drop your files here to upload it to the card" : "Thả tệp của bạn vào đây để tải nó lên tác vụ",
    "Enter a card title" : "Nhập tên tác vụ",
    "Add card" : "Thêm tác vụ",
    "Close" : "Đóng",
    "Sharing" : "Đang chia sẽ",
    "Tags" : "Thẻ",
    "Select users or groups to share with" : "Chọn người dùng hoặc nhóm để chia sẽ với",
    "Group" : "N",
    "Circle" : "Vòng kết nối",
    "No matching user or group found." : "Không tìm thấy người dùng hoặc nhóm.",
    "Loading" : "Đang tải",
    "Edit" : "Chỉnh sửa",
    "Share" : "Chia sẽ",
    "Manage" : "Quản lý",
    "Discard share" : "Hủy chia sẽ",
    "Create" : "Tạo",
    "Create a new tag" : "Tạo một thẻ mới",
    "Status" : "Trạng thái",
    "No archived boards to display" : "Không có dự án đã lưu trữ nào để hiển thị",
    "No shared boards to display" : "Không có dự án đã được chia sẽ nào để hiển thị",
    "Title" : "Tên",
    "Members" : "Thành viên",
    "More actions" : "Nhiều hành động hơn",
    "Edit board" : "Chỉnh sửa dự án",
    "Archive board" : "Lưu trữ dự án",
    "Unarchive board" : "Bỏ lưu trữ dự án",
    "Delete board" : "Xóa dự án",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "Hoàn tác dự án đã xóa - Nếu không, Dự án sẽ bị xóa trong lần quét Hệ thống tiếp theo.",
    "Create new board" : "Tạo dự án mới",
    "New board title" : "Tên dự án mới",
    "Select an attachment" : "Chọn một đính kèm",
    "Cancel upload" : "Hủy tải lên",
    "by" : "bởi",
    "Undo file deletion - Otherwise the file will be deleted during the next cronjob run." : "Hoàn tác file đã xóa - Nếu không, file sẽ bị xóa trong lần quét hệ thống tiếp theo.",
    "Undo file deletion" : "Hoàn tác file đã xóa",
    "Insert the file into the description" : "Chèn tệp vào mô tả",
    "Modified:" : "Đã sửa:",
    "Created:" : "Đã tạo:",
    "Choose a tag" : "Chọn một thẻ",
    "Add a tag" : "Thêm một thẻ",
    "Select tags" : "Chọn một thẻ",
    "Assign users" : "Chỉ định người dùng",
    "Choose a user to assign" : "Chọn một người dùng để phân công",
    "Assign this card to a user" : "Phân công tác vụ cho người dùng",
    "Due date" : "Thời hạn",
    "Click to set" : "Bấm để thiết đặt",
    "Remove due date" : "Xóa thời hạn",
    "Description" : "Mô tả",
    "Attachments" : "Đính kèm",
    "Saved" : "Đã lưu",
    "Unsaved changes" : "Thay đổi chưa được lưu",
    "Insert attachment" : "Thêm đính kèm",
    "Formatting help" : "Định dạng trợ giúp",
    "Upload attachment" : "Tải lên một đính kèm",
    "Add a card description…" : "Thêm một mô tả tác vụ...",
    "Shared boards" : "Chia sẽ dự án",
    "Move board to archive" : "Di chuyển dự án sang lưu trữ",
    "Create a new board" : "Tạo dự án mới",
    "Settings" : "Thiết lập"
},
"nplurals=1; plural=0;");
